@@ -13,10 +13,14 @@ PKG_NAME="mate-control-center"
 }
 
 which mate-autogen || {
-    echo "You need to install mate-common from the MATE Git"
+    echo "You need to install mate-common"
     exit 1
 }
 
+which yelp-build || {
+    echo "You need to install yelp-tools" 
+}
+
 REQUIRED_AUTOMAKE_VERSION=1.9
 USE_MATE2_MACROS=1
 USE_COMMON_DOC_BUILD=yes
