@@ -40,8 +40,11 @@ init_appearance_data (int *argc, char ***argv, GOptionContext *context)
   GtkBuilder *ui;
   GError *err = NULL;
 
+#if !GTK_CHECK_VERSION (3, 0, 0)
   gdk_threads_init ();
   gdk_threads_enter ();
+#endif
+
   theme_thumbnail_factory_init (*argc, *argv);
   capplet_init (context, argc, argv);
   activate_settings_daemon ();
@@ -236,7 +239,10 @@ main (int argc, char **argv)
 
   /* start the mainloop */
   gtk_main ();
+
+#if !GTK_CHECK_VERSION (3, 0, 0)
   gdk_threads_leave ();
+#endif
 
   /* free stuff */
   g_free (data);
